# Ibkr-event-daemon

### Overview

A lightweight event handling tool for Interactive Brokers based on the ibevent library. This project automates the process of capturing, triggering, and dispatching events from the IBKR trading platform.

### Installation

```bash
pip install ibkr_event_daemon
# or
poetry add ibkr_event_daemon